==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Xuất bản thất bại: vì backend không đọc được hoặc nó không cho ra bài nào cả.',
	'avis_echec_syndication_02' => 'Xuất bản thất bại: không thể nối vào backend của trang web này.',
	'avis_site_introuvable' => 'Không tìm được trang web',
	'avis_site_syndique_probleme' => 'Cảnh báo: gặp trở ngại khi syndicate website này; thành ra hệ thống bị gián đoạn tạm thời. Xin xem lại địa chỉ của hồ sơ syndication của website (<b>@url_syndic@</b>), và làm lại việc thu hồi dữ kiện. Báo Động: lúc syndicate trang web này thì gặp vấn đề; vì vậy mà hệ thống bị gián đoạn tạm thời. Xin xem lại địa chỉ của hồ sơ syndication của trang web này (<b>@url_syndic@</b>), và tìm cách thâu hồi dữ kiện lại.', # MODIF
	'avis_sites_probleme_syndication' => 'Trang web này gặp phải vấn đề khi xuất bản',
	'avis_sites_syndiques_probleme' => 'Những website xuất bản song hành này cho biết có vấn đề',

	// B
	'bouton_radio_modere_posteriori' => 'đăng trước, xét sau', # MODIF
	'bouton_radio_modere_priori' => 'xét trước, đăng sau', # MODIF
	'bouton_radio_non_syndication' => 'Không có syndication',
	'bouton_radio_syndication' => 'Syndication:',

	// E
	'entree_adresse_fichier_syndication' => 'Địa chỉ của hồ sơ «backend» để syndicate:', # MODIF
	'entree_adresse_site' => '<b>Địa chỉ Website</b> [Bắt buộc]',
	'entree_description_site' => 'Mô tả website',

	// F
	'form_prop_nom_site' => 'Tên trang web',

	// I
	'icone_modifier_site' => 'Sửa liên kết này',
	'icone_referencer_nouveau_site' => 'Thêm một điểm nối vào trang Web khác',
	'icone_voir_sites_references' => 'Xem những liên kết',
	'info_a_valider' => '[chờ thông qua]',
	'info_bloquer' => 'ngăn chận',
	'info_bloquer_lien' => 'chặn điểm nối này',
	'info_derniere_syndication' => 'Xuất bản song hành chót của website này xảy ra vào ',
	'info_liens_syndiques_1' => 'điểm kết nối syndicated',
	'info_liens_syndiques_2' => 'chờ thông qua.',
	'info_nom_site_2' => '<b>Tên website</b> [Bắt buộc]',
	'info_panne_site_syndique' => 'Website syndicated bị vấn đề',
	'info_probleme_grave' => 'lỗi của',
	'info_question_proposer_site' => 'Ai có quyền đề nghị các website nối kết?',
	'info_retablir_lien' => 'Phục hồi điểm nối kết này',
	'info_site_attente' => 'Chờ chấp thuận website',
	'info_site_propose' => 'website đã nộp lúc:',
	'info_site_reference' => 'Website nối kết online',
	'info_site_refuse' => 'Website bị từ chối',
	'info_site_syndique' => 'Website này được syndicated...', # MODIF
	'info_site_valider' => 'Website chờ chấp thuận',
	'info_sites_referencer' => 'Nối kết một website',
	'info_sites_refuses' => 'Website bị từ chối',
	'info_statut_site_1' => 'Website này là:',
	'info_statut_site_2' => 'Đã phát hành',
	'info_statut_site_3' => 'Đã nộp vào',
	'info_statut_site_4' => 'Vô thùng rác', # MODIF
	'info_syndication' => 'phát hành:',
	'info_syndication_articles' => 'bài',
	'item_bloquer_liens_syndiques' => 'Ngăn lại, không chấp thuận các điểm nối syndicated',
	'item_gerer_annuaire_site_web' => 'Quản trị thư mục website',
	'item_non_bloquer_liens_syndiques' => 'Không ngăn chặn các điểm nối kết từ syndication',
	'item_non_gerer_annuaire_site_web' => 'Tắt thư mục websites',
	'item_non_utiliser_syndication' => 'Đừng dùng syndication tự động',
	'item_utiliser_syndication' => 'Dùng syndication tự động',

	// L
	'lien_mise_a_jour_syndication' => 'Cập nhật bây giờ',
	'lien_nouvelle_recuperation' => 'Thử tìm cách thu hồi dữ kiện',

	// S
	'syndic_choix_moderation' => 'Các nối kết sắp tới từ trang web này được giải quyết ra sao?',
	'syndic_choix_oublier' => 'Giải quyết ra sao với các nối kết không còn nằm trong tập hồ sơ syndication?',
	'syndic_lien_obsolete' => 'nối kết không dùng nữa',
	'syndic_option_miroir' => 'tự động ngăn chúng',
	'syndic_option_oubli' => 'xoá chúng (sau @mois@ tháng)',
	'syndic_options' => 'Các đặc tính syndication:',

	// T
	'texte_liens_sites_syndiques' => 'Những điểm nối từ website syndicated có thể được chặn trước; lối bố trí sau đây cho thấy cách bố trí định sẵn cho những website syndicated khi được lập ra. Có thể ngăn chặn từng điểm nối một, hoặc chặn tất cả các điểm nối đến từ bất cứ website nào.', # MODIF
	'texte_messages_publics' => 'Thư tín công cộng của bài:',
	'texte_non_fonction_referencement' => 'Bạn có thể chọn không dùng đặc điểm tự động này, và tự tay cho vào dữ kiện... ', # MODIF
	'texte_referencement_automatique' => '<b>Nối kết website tự động</b> Bạn có thể nối kết một website nhanh chóng bằng cách cho vào dưới đây địa chỉ URL, hay địa chỉ của hồ sơ backend. SPIP sẽ tự động thu thập lấy các dữ kiện liên hệ đến website đó (tựa đề, mô tả ...).', # MODIF
	'texte_syndication' => 'Nếu website cho phép, bạn có thể truy tìm tự động danh sách các dữ liệu mới nhất. Để làm chuyện này, bạn phải mở đặc điểm syndication lên. <blockquote><i>Một số máy không cho phép dùng chức năng này, trong trường hợp đó, bạn không dùng đặc điểm syndication từ website của bạn được.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Những bài vỡ từng xuất bản bị thu hồi ra khỏi trang web.',
	'titre_dernier_article_syndique' => 'Những bài vừa được liên kết',
	'titre_page_sites_tous' => 'Trang nối kết',
	'titre_referencement_sites' => 'Nối kết và syndicate website',
	'titre_site_numero' => 'SỐ THỨ TỰ WEBSITE:',
	'titre_sites_proposes' => 'Trang đã nộp',
	'titre_sites_references_rubrique' => 'Các trang tham khảo trong mục này',
	'titre_sites_syndiques' => 'Trang đã xuất bản',
	'titre_sites_tous' => 'Trang tham khảo',
	'titre_syndication' => 'Syndicate trang web'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Xuất bản thất bại: vì backend không đọc được hoặc nó không cho ra bài nào cả.',
	'avis_echec_syndication_02' => 'Xuất bản thất bại: không thể nối vào backend của trang web này.',
	'avis_site_introuvable' => 'Không tìm được trang web',
	'avis_site_syndique_probleme' => 'Cảnh báo: gặp trở ngại khi syndicate website này; thành ra hệ thống bị gián đoạn tạm thời. Xin xem lại địa chỉ của hồ sơ syndication của website (<b>@url_syndic@</b>), và làm lại việc thu hồi dữ kiện. Báo Động: lúc syndicate trang web này thì gặp vấn đề; vì vậy mà hệ thống bị gián đoạn tạm thời. Xin xem lại địa chỉ của hồ sơ syndication của trang web này (<b>@url_syndic@</b>), và tìm cách thâu hồi dữ kiện lại.', # MODIF
	'avis_sites_probleme_syndication' => 'Trang web này gặp phải vấn đề khi xuất bản',
	'avis_sites_syndiques_probleme' => 'Những website xuất bản song hành này cho biết có vấn đề',

	// B
	'bouton_radio_modere_posteriori' => 'đăng trước, xét sau', # MODIF
	'bouton_radio_modere_priori' => 'xét trước, đăng sau', # MODIF
	'bouton_radio_non_syndication' => 'Không có syndication',
	'bouton_radio_syndication' => 'Syndication:',

	// E
	'entree_adresse_fichier_syndication' => 'Địa chỉ của hồ sơ «backend» để syndicate:', # MODIF
	'entree_adresse_site' => '<b>Địa chỉ Website</b> [Bắt buộc]',
	'entree_description_site' => 'Mô tả website',

	// F
	'form_prop_nom_site' => 'Tên trang web',

	// I
	'icone_modifier_site' => 'Sửa liên kết này',
	'icone_referencer_nouveau_site' => 'Thêm một điểm nối vào trang Web khác',
	'icone_voir_sites_references' => 'Xem những liên kết',
	'info_1_site' => '1 trang web',
	'info_a_valider' => '[chờ thông qua]',
	'info_bloquer' => 'ngăn chận',
	'info_bloquer_lien' => 'chặn điểm nối này',
	'info_derniere_syndication' => 'Xuất bản song hành chót của website này xảy ra vào ',
	'info_liens_syndiques_1' => 'điểm kết nối syndicated',
	'info_liens_syndiques_2' => 'chờ thông qua.',
	'info_nom_site_2' => '<b>Tên website</b> [Bắt buộc]',
	'info_panne_site_syndique' => 'Website syndicated bị vấn đề',
	'info_probleme_grave' => 'lỗi của',
	'info_question_proposer_site' => 'Ai có quyền đề nghị các website nối kết?',
	'info_retablir_lien' => 'Phục hồi điểm nối kết này',
	'info_site_attente' => 'Chờ chấp thuận website',
	'info_site_propose' => 'website đã nộp lúc:',
	'info_site_reference' => 'Website nối kết online',
	'info_site_refuse' => 'Website bị từ chối',
	'info_site_syndique' => 'Website này được syndicated...', # MODIF
	'info_site_valider' => 'Website chờ chấp thuận',
	'info_sites_referencer' => 'Nối kết một website',
	'info_sites_refuses' => 'Website bị từ chối',
	'info_statut_site_1' => 'Website này là:',
	'info_statut_site_2' => 'Đã phát hành',
	'info_statut_site_3' => 'Đã nộp vào',
	'info_statut_site_4' => 'Vô thùng rác', # MODIF
	'info_syndication' => 'phát hành:',
	'info_syndication_articles' => 'bài',
	'item_bloquer_liens_syndiques' => 'Ngăn lại, không chấp thuận các điểm nối syndicated',
	'item_gerer_annuaire_site_web' => 'Quản trị thư mục website',
	'item_non_bloquer_liens_syndiques' => 'Không ngăn chặn các điểm nối kết từ syndication',
	'item_non_gerer_annuaire_site_web' => 'Tắt thư mục websites',
	'item_non_utiliser_syndication' => 'Đừng dùng syndication tự động',
	'item_utiliser_syndication' => 'Dùng syndication tự động',

	// L
	'lien_mise_a_jour_syndication' => 'Cập nhật bây giờ',
	'lien_nouvelle_recuperation' => 'Thử tìm cách thu hồi dữ kiện',

	// S
	'syndic_choix_moderation' => 'Các nối kết sắp tới từ trang web này được giải quyết ra sao?',
	'syndic_choix_oublier' => 'Giải quyết ra sao với các nối kết không còn nằm trong tập hồ sơ syndication?',
	'syndic_lien_obsolete' => 'nối kết không dùng nữa',
	'syndic_option_miroir' => 'tự động ngăn chúng',
	'syndic_option_oubli' => 'xoá chúng (sau @mois@ tháng)',
	'syndic_options' => 'Các đặc tính syndication:',

	// T
	'texte_liens_sites_syndiques' => 'Những điểm nối từ website syndicated có thể được chặn trước; lối bố trí sau đây cho thấy cách bố trí định sẵn cho những website syndicated khi được lập ra. Có thể ngăn chặn từng điểm nối một, hoặc chặn tất cả các điểm nối đến từ bất cứ website nào.', # MODIF
	'texte_messages_publics' => 'Thư tín công cộng của bài:',
	'texte_non_fonction_referencement' => 'Bạn có thể chọn không dùng đặc điểm tự động này, và tự tay cho vào dữ kiện... ', # MODIF
	'texte_referencement_automatique' => '<b>Nối kết website tự động</b> Bạn có thể nối kết một website nhanh chóng bằng cách cho vào dưới đây địa chỉ URL, hay địa chỉ của hồ sơ backend. SPIP sẽ tự động thu thập lấy các dữ kiện liên hệ đến website đó (tựa đề, mô tả ...).', # MODIF
	'texte_syndication' => 'Nếu website cho phép, bạn có thể truy tìm tự động danh sách các dữ liệu mới nhất. Để làm chuyện này, bạn phải mở đặc điểm syndication lên. <blockquote><i>Một số máy không cho phép dùng chức năng này, trong trường hợp đó, bạn không dùng đặc điểm syndication từ website của bạn được.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Những bài vỡ từng xuất bản bị thu hồi ra khỏi trang web.',
	'titre_dernier_article_syndique' => 'Những bài vừa được liên kết',
	'titre_page_sites_tous' => 'Trang nối kết',
	'titre_referencement_sites' => 'Nối kết và syndicate website',
	'titre_site_numero' => 'SỐ THỨ TỰ WEBSITE:',
	'titre_sites_proposes' => 'Trang đã nộp',
	'titre_sites_references_rubrique' => 'Các trang tham khảo trong mục này',
	'titre_sites_syndiques' => 'Trang đã xuất bản',
	'titre_sites_tous' => 'Trang tham khảo',
	'titre_syndication' => 'Syndicate trang web'
);

?>
